# InstallUlt

This Pip Package is to Install Ultroid on Your Local Machine or VPS.

Instructions Will Be Given later.

For Support Join [@UltroidSupport](https://t.me/UltroidSupport)
For Updates Join [@TheUltroid](https://t.me/TheUltroid)

Main Repository :- https://github.com/TeamUltroid/Ultroid